@@ -18,7 +18,7 @@ from . import imgcif2mcstas, create_attributes, set_dependency
 
 
 def generate_image_data(shape, filename):
-    data = numpy.zeros(shape[1:], dtype="u1")
+    data = numpy.zeros(shape[1:], dtype="i4")
     with h5py.File(filename, "w") as datafile:
         dset = datafile.create_dataset(
             "data",
@@ -29,8 +29,9 @@ def generate_image_data(shape, filename):
         )
         # Actually write the data in
         for i in range(shape[0]):
-            dset[i, :, :] += data
-        print(f"{shape[0]} images written.")
+            start_dset = dset[i, :, :]
+            dset[i, :, :] = start_dset + data
+    print(f"{shape[0]} images written.")
 
 
 # TODO add only link to files in nxdata
@@ -88,8 +89,8 @@ class NexusWriter:
     ):
         # assumes fast and slow axis vectors have already been converted if needed
         # Scaled center
-        x_scaled = beam_center_xy[0] * xy_pixel_size[0]
-        y_scaled = beam_center_xy[1] * xy_pixel_size[1]
+        x_scaled = beam_center_xy[0] * (xy_pixel_size[0] / 1000)
+        y_scaled = beam_center_xy[1] * (xy_pixel_size[1] / 1000)
         # Detector origin
         det_origin = x_scaled * numpy.array(fast_axis_v) + y_scaled * numpy.array(
             slow_axis_v
@@ -135,7 +136,7 @@ class NexusWriter:
                 dset_shape = (len(_scan_range),) + tuple(self.detector.image_size)
 
             generate_image_data(dset_shape, self._datafile)
-            nxdata["datafile"] = h5py.ExternalLink(self._datafile, "data")
+            nxdata["data"] = h5py.ExternalLink(self._datafile, "data")
         else:
             # TODO This needs some serious rethinking at some point
             dirname = os.path.dirname(self._nxs.filename)
